==> liquidsoap_1.4.3.orig.tar.bz2: liquidsoap-1.4.3/README.md <==
Liquidsoap
==========

Our flagship is Liquidsoap, a swiss-army knife for multimedia streaming, notably
used for netradios and webtvs. It has tons of features, it's free and it's
open-source!

Liquidsoap is a powerful and flexible language for describing your streams. It
offers a rich collection of operators that you can combine to create and
transform streams. Liquidsoap is very light and easy to use, in the Unix
tradition of simple strong components working together.

Copyright 2003-2019 Savonet team

[![GPL license](https://img.shields.io/badge/License-GPL-green.svg)](https://github.com/savonet/liquidsoap/blob/master/COPYING)
[![GitHub release](https://img.shields.io/github/release/savonet/liquidsoap.svg)](https://GitHub.com/savonet/liquidsoap/releases/)
[![Install with Opam !](https://img.shields.io/badge/Install%20with-Opam-1abc9c.svg)](http://opam.ocaml.org/packages/liquidsoap/)
[![Chat on slack !](https://img.shields.io/badge/Chat%20on-Slack-1a1f9c.svg)](http://slack.liquidsoap.info/)

|              |                                              |
| ------------ | -------------------------------------------- |
| Slack Chat   | http://slack.liquidsoap.info                 |
| IRC          | #savonet on [irc.freenode.net](https://freenode.net/) (slack bridge)  |
| Mailing list | savonet-users@lists.sourceforge.net          |
| Homepage     | http://liquidsoap.info                       |
| Bug reports  | https://github.com/savonet/liquidsoap/issues |

Installation
------------

See the [install.md](doc/content/install.md) file.

Documentation
-------------

HTML documentation is in doc/html/index.html
([mirrored](https://www.liquidsoap.info/doc.html) on the [Savonet
website](http://liquidsoap.info))

License
-------

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 2 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details, fully
stated in the COPYING file at the root of the liquidsoap distribution.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 59 Temple
Place, Suite 330, Boston, MA 02111-1307 USA

Authors
-------

* Developers:
  * [David Baelde](http://www.lsv.fr/~baelde/)
  * [Romain Beauxis](https://github.com/toots)
  * [Samuel Mimram](http://www.mimram.fr)
* Contributors:
  * Florent   Bouchez
  * Julien    Cristau
  * Stéphane  Gimenez
  * Clément   Renard
  * Vincent   Tabard
  * Sattisvar Tandabany

==> liquidsoap_2.0.2.orig.tar.bz2: liquidsoap-2.0.2/README.md <==
Liquidsoap
==========

Our flagship is Liquidsoap, a swiss-army knife for multimedia streaming, notably
used for netradios and webtvs. It has tons of features, it's free and it's
open-source!

Liquidsoap is a powerful and flexible language for describing your streams. It
offers a rich collection of operators that you can combine to create and
transform streams. Liquidsoap is very light and easy to use, in the Unix
tradition of simple strong components working together.

Copyright 2003-2021 Savonet team

[![GPL license](https://img.shields.io/badge/License-GPL-green.svg)](https://github.com/savonet/liquidsoap/blob/master/COPYING)
![CI](https://github.com/savonet/liquidsoap/workflows/CI/badge.svg)
[![GitHub release](https://img.shields.io/github/release/savonet/liquidsoap.svg)](https://GitHub.com/savonet/liquidsoap/releases/)
[![Install with Opam !](https://img.shields.io/badge/Install%20with-Opam-1abc9c.svg)](http://opam.ocaml.org/packages/liquidsoap/)
[![Chat on slack !](https://img.shields.io/badge/Chat%20on-Slack-1a1f9c.svg)](http://slack.liquidsoap.info/)

|                |                                              |
| -------------- | -------------------------------------------- |
| Slack Chat     | http://slack.liquidsoap.info                 |
| IRC            | #savonet on [irc.libera.chat](https://libera.chat/) (slack bridge)  |
| Mailing list.  | savonet-users@lists.sourceforge.net          |
| Homepage       | http://liquidsoap.info                       |
| Bug reports    | https://github.com/savonet/liquidsoap/issues |
| User questions | https://github.com/savonet/liquidsoap/discussions |

Installation
------------

See the instructions [here](https://www.liquidsoap.info/doc.html?path=install.html).

Documentation
-------------

HTML documentation is in doc/html/index.html
([mirrored](https://www.liquidsoap.info/doc.html) on the [Savonet
website](http://liquidsoap.info))

We also have written _the Liquidsoap book_ which is [available
online](http://www.liquidsoap.info/book/book.pdf) and in [physical
version](https://www.amazon.com/dp/B095PVTYR3).

License
-------

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; either version 2 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details, fully
stated in the COPYING file at the root of the liquidsoap distribution.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 59 Temple
Place, Suite 330, Boston, MA 02111-1307 USA

Authors
-------

* Developers:
  * [David Baelde](http://www.lsv.fr/~baelde/)
  * [Romain Beauxis](https://github.com/toots)
  * [Samuel Mimram](http://www.mimram.fr)
* Contributors:
  * Florent   Bouchez
  * Julien    Cristau
  * Stéphane  Gimenez
  * Clément   Renard
  * Vincent   Tabard
  * Sattisvar Tandabany
